﻿// hmcMetadaten.jsx
// Copyright © by Manfred Clemens erstellt: 12.03.2013, letzte Änderung: 06.10.2013
// ********************************************************************************
/* 
  PROGRAMMBESCHREIBUNG:
  Das Programm speichert die Angaben, die in den Variablen 'Benutzer-Einstellungen' 
  s. u. definiert wurden, als Metadaten in das aktuell geöffnete Bilddokument. 
  Bei gewählter Option 'Alle Metadaten löschen' werden alle Metadaten entfernt,
  auch die nur leseberechtigten Kameradaten. Diese Datenlöschung, wird durch die 
  Erstellung eines neuen Dokumentes realisiert. Die so neu erstellte Datei ohne
  Matadaten, erhält im Dateinamen den Zusatz '_copy'. Bei einer PSD-Bilddokument
  das aus mehreren Ebenen besteht, werden die Ebenen im neuen Dokument auf die
  Hintergrundebene (flatten) reduziert.
  
  Hinweis:  Die Metadaten können in PS über 'Menü > Datei > Dateiinformationen...'
            angezeigt/editiert werden!
 
  INSTALLATION IN PHOTOSHOP & SKRIPTAUFRUF:
  Die Datei 'hmcMetadaten.jsx' in das Verzeichnis
  'c:\Programme\Adobe\Adobe Photoshop CS6\Presets\Scripts' kopieren und Photoshop
  neu starten, danach ein Bilddokument in Photoshop öffnen und den Menübefehl
  'Menü > Datei > Skripten > hmcMetadaten' aufrufen und anwenden.
*/  
#target Photoshop
#strict on

// Benutzer Einstellungen
var scriptName = "hmcMetadaten";
var scriptVersion = " 1.1";


// ********************** Metadaten im Register Beschreibung ***********************
var infoTitle = "Dokumenttitel";                      // Dokumenttitel
var infoAuthor = "Hans Josef";                        // Autor
var infoAuthorPosition = "Firma";                     // Autorentitel
var infoCaption = "Bild-Beschreibung";                // Beschreibung
var infoCaptionWriter = " Mustermann ";               // Verfassser der Beschreibung
var infoKeyworts = ["Eins","Zwei","Drei","Vier"];     // Stichwörter
var copyrightedType = CopyrightedType.PUBLICDOMAIN;   // Copyright-Status
var copyrightNotice = "© 2013 Mustermann";            // Copyright-Informationen
var ownerUrl = "www.meinewebsite.de";                 // Url für Copyright-Inform.
// ********************** Metadaten im Register Ursprung ***************************
var infoCity = "Düsseldorf";                          // Ort
var infoProvinceState = "NRW";                        // Bundesland/Provinz
var infoCountry = "Deutschland";                      // Land
var infoCredit = "keine";                             // Mitwirkende
var infoSource = "Quellangaben";                      // Quelle
var infoHeadline = "Meine Überschrift";               // Überschrift
var infoInstructions = "keine Anweisungen";           // Anweisungen
var infoTransmissonReference = "keine Angabe";        // Übertragungsreferenz
// ****************************** Ende Metadaten  *******************************

try {
  
    function getFileName(filename) {
      // im Dateinamen den Zusatz '_copy' einfügen
      var name = filename.split('.');
      return name[0] + "_copy." + name[1];
    }  
  
    function delateAllMetadata() {
    
      // Infos vom aktiven Dokument
      var width = app.activeDocument.width.value;
      var height = app.activeDocument.height.value;
      var resolution = app.activeDocument.resolution;
      var name = app.activeDocument.name;
      name = getFileName (name);
      
      // Wenn meherer Ebenen existieren, dann auf Hintergrundebene reduzieren
      if (app.activeDocument.artLayers.length-1 > 0) {
        app.activeDocument.flatten();
      }
  
      
      // Auswahlbereich ums Bild legen
      //app.activeDocument.selection.All();
      var region = [[0,0],[0,width],[width,height],[width,0]];
      app.activeDocument.selection.select (region);
    
      // Bild-Auswahlbereich in die Zwischenablage legen
      app.activeDocument.selection.copy();
    
      // Auswahlbereich wieder aufheben
      app.activeDocument.selection.deselect();
      
      // neues Dokument mit den gleichen Abmessungen erzeugen
      documents.add (width, height, resolution, name, NewDocumentMode.RGB, 
                                                          DocumentFill.TRANSPARENT);
       
      // Bild-Auswahlbereich aus der Zwischenablage in das neue Dokument einfügen
      app.activeDocument.paste();
      
      // Zwischenablage entleeren
      purge(PurgeTarget.CLIPBOARDCACHE);
      
    } 
  
  // Bildinformationen im Bilddokument speichern
  function setImageInformation() {
    with (app.activeDocument) {
      info.title = infoTitle;                     // Dokumenttitel
      info.author = infoAuthor;                   // Autor
      info.authorPosition = infoAuthorPosition;   // Autorentitel
      info.caption = infoCaption;                 // Beschreibung
      info.captionWriter = infoCaptionWriter;     // Verfassser der Beschreibung
      info.keywords = infoKeyworts;               // Stichwörter       
      info.copyrighted = copyrightedType;         // Copyright-Status
      info.copyrightNotice = copyrightNotice;     // Copyright-Informationen
      info.ownerUrl = ownerUrl;                   // Url für Copyright-Informationen
  
      info.city = infoCity;                       // Ort
      info.provinceState = infoProvinceState;     // Bundesland/Provinz
      info.country = infoCountry;                 // Land
      info.credit = infoCredit;                   // Mitwirkende
      info.source = infoSource;                   // Quelle
      info.headline = infoHeadline;               // Überschrift
      info.instructions = infoInstructions;       // Anweisungen
      info.transmissionReference = infoTransmissonReference; // Übertragungsreferenz
      info.urgency.Urgency.NORMAL;                // Dringlichkeit
      
    }  
  }  
  
  function CreateDialog() { 
    this.windowRef = null; 

    // **************************************************************************
    // ***                        Dialog hinzufügen                           ***
    // **************************************************************************

    var dlg = new Window("dialog", scriptName + scriptVersion ,[100,100,380,265]); 
    this.windowRef = dlg;
  
    // **************************************************************************
    // ***                        Panel hinzufügen                            ***
    // **************************************************************************
    dlg.infoPanel = dlg.add("panel", [10,10,270,85], ""); 
    with (dlg.infoPanel) {
      // StaticText hinzufügen
      infoFileName = add('statictext',[10,10,260,25], 
                          "Dateinname: " + app.activeDocument.name);
      rbtSaveNewData = add('radiobutton', [10,30,250,45], 
                          "Neue Metadaten speichern");
      rbtSaveNewData.value = true;
      rbtClearMetaData = add('radiobutton', [10,50,250,65], 
                          "Alle Metadaten löschen");
    }

    // **************************************************************************
    // ***                        Panel hinzufügen                            ***
    // **************************************************************************
    dlg.btnPanel = dlg.add("panel", [10,100,270,150], "");
    with (dlg.btnPanel) {
      // Button's hinzufügen
      okBtn = dlg.btnPanel.add("button", [10,10,110,35], "OK");
      cancelBtn = dlg.btnPanel.add("button", [145,10,245,35], "Abbruch");

      // ************************************************************************
      // ***                  Klick-Ereignise auswerten                       ***
      // ************************************************************************
      // OK-Button
      okBtn.onClick = function() {
        if (rbtSaveNewData.value == true) {
          setImageInformation();
          alert ("Neue Metadaten wurden gespeichert.", "Hinweis");
        }
        if (rbtClearMetaData.value == true) {
          delateAllMetadata();
          alert ("Alle Metadaten wurden gelöscht.", "Hinweis");
        }
        dlg.close();
      }
    
      // Abbruch-Button
      cancelBtn.onClick = function() {
        dlg.close();
      }
    }
   
    // **************************************************************************
    // ***                 Dialog anzeigen und plazieren                      ***
    // **************************************************************************
    //dlg.center();
    dlg.frameLocation = [600,100];              // Dialog-Fenster plazieren
    dlg.show();                                 // Dialog-Fenster anzeigen
    //return true;

    // Original PS-Einstellungen wieder zurücksetzen
    function Cleanup() {
      app.preferences.rulerUnits = defaultRulerUnits;
      app.preferences.typeUnits = defaultTypeUnits;
      app.DisplayDialogs = defaultDisplayDialogs;
      return;
    }
}

// ******************************************************************************
// ***                    Hauptprogramm - Programmstart                       ***
// ******************************************************************************
// Ist überhaupt ein Dokument geöffnet?
if (documents.length > 0) {
    try {
        app.bringToFront(); // Zunächst wird Photoshop in den Vordergrund geholt
        // Original Einstellungen speichern und die gewünschte Maßeinheit setzen        
        var defaultRulerUnits = app.preferences.rulerUnits;
        var defaultTypeUnits = app.preferences.typeUnits;
        var defaultDisplayDialogs = app.DisplayDialogs;
        if (defaultRulerUnits != Units.PIXELS) {
          preferences.rulerUnits = Units.PIXELS; 
        }
        CreateDialog(); // Hauptprogramm - Programmstart
        
    } catch(e) {        // Fehler anzeigen
        if (e.line != undefined)
            alert(scriptName + " Zeile[" + e.line + "] " + e);
        else
            alert(scriptName + " " + e);
        Cleanup();    
        }
} else {
    alert(scriptName + " Es ist kein Bilddokument geöffnet!");
}

// Speicher wieder freimachen
scriptName = null;
scriptVersion = null;
width = null;
height = null;
resolution = null;

} // try Ende
catch (e) {
  alert (e.description, "Fehler!");
} // EOF